@@ -18,6 +18,7 @@ class LogHandle(object):
     __gui_console = None
     __write_pipe = None
     __read_pipe = None
+    __pipe_thread = None
 
     """
     Logging that becomes easier and more uniformed
@@ -33,14 +34,21 @@ class LogHandle(object):
 
         self.file_dir = file_dir
         self.base_name = base_name
-        self.__write_pipe, self.__read_pipe = Pipe()
         self.__printable = set(string.printable)
-        p = Thread(target=self.__pipe_listen)
-        p.daemon = True
-        p.start()
 
     @property
     def write_pipe(self):
+        if not self.__write_pipe:
+            if self.__read_pipe:
+                self.__read_pipe.close()
+
+            self.__write_pipe, self.__read_pipe = Pipe()
+
+        if not self.__pipe_thread:
+            self.__pipe_thread = Thread(target=self.__pipe_listen)
+            self.__pipe_thread.daemon = True
+            self.__pipe_thread.start()
+
         return self.__write_pipe
 
     @property
@@ -106,11 +114,10 @@ class LogHandle(object):
             self.__gui_console = gui_obj
             self.__gui_console.log_setup(log_class=self)
         else:
-            self.__write_pipe.send({'command': 'gui_console','title': title, 'destroy': destroy, 'turn_off': turn_off})
+            self.__write_pipe.send({'command': 'gui_console', 'title': title, 'destroy': destroy, 'turn_off': turn_off})
 
     def write_to_log(self, message, action='info', print_only=False):
-        self.__write_pipe.send({'command': 'write_to_log', 'message': message, 'action': action,
-                                'print_only': print_only})
+        self.__write_to_log(message=message, action=action, print_only=print_only)
 
     def __gui_console_set(self, title=None, destroy=False, turn_off=False, *args, **kwargs):
         if self.__gui_console and destroy:
